@@ -91,6 +91,16 @@ class APIClient:
             return_json,
             self.api_helper)
 
+    def event_frames(self, query_params={}):
+        """
+        Get the Event Frames
+        :param query_params: Dictionary of filter conditions
+        :return: (EntityList) List of Event Frames belonging to the asset
+        """
+        return_json = self.api_helper.call_api(
+            Constants.GET_EVENT_FRAMES, Constants.API_GET).json()
+        return EntityFactory(Constants.EVENT_FRAME_ENTITY, return_json, self.api_helper)
+
     def list_models(
             self,
             is_active: bool = None,
@@ -118,3 +128,23 @@ class APIClient:
             Constants.MODEL_ENTITY,
             response.json(),
             self.api_helper)
+
+    def products(self, query_params={}):
+        """
+        This method is used to fetch list of all product belongs to a particular client
+        :param query_params: Dictionary of filter conditions
+        :return: Product(Product Entity) Objects
+        """
+        return_json = self.api_helper.call_api(
+            Constants.GET_PRODUCTS, Constants.API_GET, query_params=query_params).json()
+        return EntityFactory(Constants.PRODUCT_ENTITY, return_json, self.api_helper)
+
+    def sites(self, query_params={}):
+        """
+        This method is used to fetch all sites available for a user's client
+        :param query_params: Dictionary of filter conditions
+        :return: Site(Site Entity) Objects
+        """
+        return_json = self.api_helper.call_api(
+            Constants.GET_SITES, Constants.API_GET, query_params=query_params).json()
+        return EntityFactory(Constants.SITE_ENTITY, return_json, self.api_helper)
