@@ -171,8 +171,11 @@ class EntityList:
             it takes the value as "json"
         :param transformations: Refers to the list of transformations. It supports either
             interpolation or aggregation, depending upon which, we pass the value of this
-            dictionary. An example value here is:
-            
+            dictionary. If `transformation_type` is "aggregation", an optional key can be
+            passed called `aggregation_timestamp`, which determines how the timestamp information
+            will be retained after aggregation. Valid options are "first", "last" or "discard". By
+            default, the last timestamp in each group will be retained.
+            An example value here is:
             [{
                 "transformation_type": "interpolation",
                 "column": "3",
@@ -180,8 +183,8 @@ class EntityList:
             }, {
                 "transformation_type": "aggregation",
                 "aggregation_column": "4",
-                "aggregation_dict": {"3": "max"}
-
+                "aggregation_dict": {"3": "max"},
+                "aggregation_timestamp": "last",
             }]
         :return: (DataIterator) DataIterator object which can be iterated to get the data
             between the given duration
